==> ae_progress-0.0.2.tar.gz: ae_progress-0.0.2/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE AE ROOT PACKAGE. ANY CHANGES SHOULD BE DONE THERE.
  All changes will be deployed automatically to all the portions of this namespace package.
-->
# progress Portion Of ae Namespace Package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_progress/master?logo=python)](
    https://gitlab.com/ae-group/ae_progress)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_progress)](https://pypi.org/project/ae-progress/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes for to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_progress/coverage.svg)](
    https://ae-group.gitlab.io/ae_progress/coverage/ae_progress_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_progress/mypy.svg)](
    https://ae-group.gitlab.io/ae_progress/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_progress/pylint.svg)](https://ae-group.gitlab.io/ae_progress/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_progress)](https://pypi.org/project/ae-progress/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_progress)](https://pypi.org/project/ae-progress/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_progress)](https://pypi.org/project/ae-progress/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_progress)](https://pypi.org/project/ae-progress/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_progress)](https://libraries.io/pypi/ae-progress)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_progress)](https://pypi.org/project/ae-progress/#files)


## Installation

Execute the following command for to use the ae.progress module in your
application. It will install ae.progress into your python (virtual) environment:
 
```shell script
pip install ae-progress
```

If you instead want to contribute to this portion then first fork
[the ae-progress repository at GitLab](https://gitlab.com/ae-group/ae_progress "ae.progress code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_progress):

```shell script
pip install -e .[dev]
```

The last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or for to extend the portion documentation.
For to contribute only to the unit tests or the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## Namespace Portion Documentation

More info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.progress.html#module-ae.progress
"ae_progress documentation").

<!-- Common files version 0.0.29 deployed (with 0.0.29)
     to the ae_progress module version 0.0.1.
-->

==> ae_progress-0.0.4.tar.gz: ae_progress-0.0.4/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE AE ROOT PACKAGE. ANY CHANGES SHOULD BE DONE THERE.
  All changes will be deployed automatically to all the portions of this namespace package.
-->
# progress Portion Of ae Namespace Package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_progress/master?logo=python)](
    https://gitlab.com/ae-group/ae_progress)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_progress)](
    https://pypi.org/project/ae-progress/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes for to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_progress/coverage.svg)](
    https://ae-group.gitlab.io/ae_progress/coverage/ae_progress_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_progress/mypy.svg)](
    https://ae-group.gitlab.io/ae_progress/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_progress/pylint.svg)](
    https://ae-group.gitlab.io/ae_progress/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_progress)](
    https://pypi.org/project/ae-progress/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_progress)](
    https://pypi.org/project/ae-progress/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_progress)](
    https://pypi.org/project/ae-progress/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_progress)](
    https://pypi.org/project/ae-progress/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_progress)](
    https://libraries.io/pypi/ae-progress)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_progress)](
    https://pypi.org/project/ae-progress/#files)


## Installation

Execute the following command for to use the ae.progress module in your
application. It will install ae.progress into your python (virtual) environment:
 
```shell script
pip install ae-progress
```

If you instead want to contribute to this portion then first fork
[the ae-progress repository at GitLab](https://gitlab.com/ae-group/ae_progress "ae.progress code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_progress):

```shell script
pip install -e .[dev]
```

The last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or for to extend the portion documentation.
For to contribute only to the unit tests or the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## Namespace Portion Documentation

More info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.progress.html#module-ae.progress
"ae_progress documentation").

<!-- Common files version 0.0.33 deployed (with 0.0.33)
     to the ae_progress module version 0.0.4.
-->
